A method ``clone`` has been added to ``Parameter`` to quickly deep copy the
object and change any constructor argument.
A supporting equality method is added, and ``repr`` is enhanced to be able to
roundtrip -- ``eval(repr(Parameter()))`` -- if the Parameter's arguments can
similarly roundtrip.
Parameter's arguments are made keyword-only.
